@@ -16,7 +16,7 @@ from zope.interface import Interface
 from zope.publisher.interfaces.http import IMethodNotAllowed
 
 
-class MethodNotAllowedView(object):
+class MethodNotAllowedView:
     """A view for MethodNotAllowed that renders a HTTP 405 response."""
 
     __used_for__ = IMethodNotAllowed
@@ -24,10 +24,10 @@ class MethodNotAllowedView(object):
     def __init__(self, error, request):
         self.error = error
         self.request = request
-        allow = []
 
         try:
-            # see test_methodnotallowed.TestMethodNotAllowedView.test_defaultView
+            # see
+            # test_methodnotallowed.TestMethodNotAllowedView.test_defaultView
             # I could not solve this with a while ... next() iterator
             # because it seems like once the generator had an exception it
             # stops returning items
@@ -42,4 +42,4 @@ class MethodNotAllowedView(object):
     def __call__(self):
         self.request.response.setHeader('Allow', ', '.join(self.allow))
         self.request.response.setStatus(405)
-        return 'Method Not Allowed'
+        return b'Method Not Allowed'
