@@ -15,12 +15,12 @@
 """
 __docformat__ = 'restructuredtext'
 
+from zope.interface import implementer
 from zope.publisher.interfaces.http import IHTTPException
-from zope.interface import implements
 
-class NotFound(object):
 
-    implements(IHTTPException)
+@implementer(IHTTPException)
+class NotFound:
 
     def __init__(self, context, request):
         self.context = context
@@ -28,11 +28,11 @@ class NotFound(object):
 
     def __call__(self):
         if self.request.method in ['MKCOL'] and \
-               self.request.getTraversalStack():
+                self.request.getTraversalStack():
             # MKCOL with non-existing parent.
             self.request.response.setStatus(409)
         else:
             self.request.response.setStatus(404)
-        return ''
+        return b''
 
     __str__ = __call__
