@@ -13,34 +13,39 @@
 ##############################################################################
 """Tests for HTTP error views
 """
-from unittest import TestCase, TestSuite, main, makeSuite
-from StringIO import StringIO
+from io import BytesIO
+from unittest import TestCase
+from unittest import TestSuite
+from unittest import makeSuite
 
-from zope.interface import Interface, implements
+from zope.component import provideAdapter
+from zope.interface import Interface
+from zope.interface import implementer
 from zope.publisher.http import HTTPRequest
 from zope.publisher.interfaces.http import IHTTPRequest
 
-from zope.component import provideAdapter
 
-
-class I(Interface):
+class Iface(Interface):
     pass
 
 
-class C(object):
-    implements(I)
+@implementer(Iface)
+class C:
+    pass
 
 
-class GetView(object):
+class GetView:
     def __init__(self, context, request):
         pass
+
     def GET(self):
         pass
 
 
-class DeleteView(object):
+class DeleteView:
     def __init__(self, context, request):
         pass
+
     def DELETE(self):
         pass
 
@@ -48,31 +53,32 @@ class DeleteView(object):
 class TestMethodNotAllowedView(TestCase):
 
     def setUp(self):
-        from zope.publisher.interfaces.http import IHTTPRequest
+        provideAdapter(GetView, (Iface, IHTTPRequest), Interface, 'GET')
+        provideAdapter(DeleteView, (Iface, IHTTPRequest), Interface, 'DELETE')
+        provideAdapter(GetView, (Iface, IHTTPRequest), Interface, 'irrelevant')
+        provideAdapter(
+            DeleteView, (Iface, IHTTPRequest), Interface, 'also_irrelevant')
 
-        provideAdapter(GetView, (I, IHTTPRequest), Interface, 'GET')
-        provideAdapter(DeleteView, (I, IHTTPRequest), Interface, 'DELETE')
-        provideAdapter(GetView, (I, IHTTPRequest), Interface, 'irrelevant')
-        provideAdapter(DeleteView, (I, IHTTPRequest), Interface, 'also_irr.')
-        
         from zope.publisher.interfaces import IDefaultViewName
         from zope.publisher.interfaces.browser import IBrowserRequest
-        #do the same as defaultView would for something like:
-        #<defaultView
+
+        # do the same as defaultView would for something like:
+        # <defaultView
         #    for=".test_methodnotallowed.I"
         #    name="index.html"
         #    />
 
-        provideAdapter(u'index.html', (I, IBrowserRequest), IDefaultViewName)
-    
+        provideAdapter(
+            'index.html', (Iface, IBrowserRequest), IDefaultViewName)
+
     def test(self):
         from zope.publisher.interfaces.http import MethodNotAllowed
-        from zope.app.http.exception.methodnotallowed \
-             import MethodNotAllowedView
-        from zope.publisher.http import HTTPRequest
+
+        from zope.app.http.exception.methodnotallowed import \
+            MethodNotAllowedView
 
         context = C()
-        request = HTTPRequest(StringIO('PUT /bla/bla HTTP/1.1\n\n'), {})
+        request = HTTPRequest(BytesIO(b'PUT /bla/bla HTTP/1.1\n\n'), {})
         error = MethodNotAllowed(context, request)
         view = MethodNotAllowedView(error, request)
 
@@ -80,25 +86,25 @@ class TestMethodNotAllowedView(TestCase):
 
         self.assertEqual(request.response.getStatus(), 405)
         self.assertEqual(request.response.getHeader('Allow'), 'DELETE, GET')
-        self.assertEqual(result, 'Method Not Allowed')
-
+        self.assertEqual(result, b'Method Not Allowed')
 
     def test_defaultView(self):
         # do the same with a BrowserRequest
-        # edge case is that if someone does a defaultView for the context object
-        # but the app is not prepared for webdav or whatever
+        # edge case is that if someone does a defaultView for the context
+        # object but the app is not prepared for webdav or whatever
         # and someone comes with a not allowed method, the exception
         # view fails on getAdapters
         # this might be an issue with zope.publisher, as it provides
         # a unicode object with provideAdapter, but I don't think I can
         # change zope.publisher
-        from zope.publisher.interfaces.http import MethodNotAllowed
-        from zope.app.http.exception.methodnotallowed \
-             import MethodNotAllowedView
         from zope.publisher.browser import BrowserRequest
+        from zope.publisher.interfaces.http import MethodNotAllowed
+
+        from zope.app.http.exception.methodnotallowed import \
+            MethodNotAllowedView
 
         context = C()
-        request = BrowserRequest(StringIO('PUT /bla/bla HTTP/1.1\n\n'), {})
+        request = BrowserRequest(BytesIO(b'PUT /bla/bla HTTP/1.1\n\n'), {})
 
         error = MethodNotAllowed(context, request)
         view = MethodNotAllowedView(error, request)
@@ -106,15 +112,12 @@ class TestMethodNotAllowedView(TestCase):
         result = view()
 
         self.assertEqual(request.response.getStatus(), 405)
-        #well this is empty, but we're grateful that it does not break
+        # well this is empty, but we're grateful that it does not break
         self.assertEqual(request.response.getHeader('Allow'), '')
-        self.assertEqual(result, 'Method Not Allowed')
+        self.assertEqual(result, b'Method Not Allowed')
 
 
 def test_suite():
     return TestSuite((
         makeSuite(TestMethodNotAllowedView),
-        ))
-
-if __name__=='__main__':
-    main(defaultTest='test_suite')
+    ))
