@@ -15,12 +15,12 @@
 """
 __docformat__ = 'restructuredtext'
 
+from zope.interface import implementer
 from zope.publisher.interfaces.http import IHTTPException
-from zope.interface import implements
 
-class Unauthorized(object):
 
-    implements(IHTTPException)
+@implementer(IHTTPException)
+class Unauthorized:
 
     def __init__(self, context, request):
         self.context = context
