@@ -12,30 +12,31 @@
 """HTTP `PUT` verb"""
 __docformat__ = 'restructuredtext'
 
+import zope.publisher.interfaces.http
+import zope.traversing.browser
 from zope.component import queryAdapter
 from zope.event import notify
-from zope.lifecycleevent import ObjectCreatedEvent
-from zope.interface import implements
+from zope.filerepresentation.interfaces import IFileFactory
+from zope.filerepresentation.interfaces import IReadDirectory
+from zope.filerepresentation.interfaces import IWriteDirectory
 from zope.filerepresentation.interfaces import IWriteFile
-from zope.filerepresentation.interfaces import \
-    IWriteDirectory, IReadDirectory, IFileFactory
-import zope.traversing.browser
-import zope.publisher.interfaces.http
+from zope.interface import implementer
+from zope.lifecycleevent import ObjectCreatedEvent
+
 from zope.app.http.interfaces import INullResource
 
 
-class NullResource(object):
+@implementer(INullResource)
+class NullResource:
     """Object representing objects to be created by a `PUT`.
     """
 
-    implements(INullResource)
-
     def __init__(self, container, name):
         self.container = container
         self.name = name
 
 
-class NullPUT(object):
+class NullPUT:
     """Put handler for null resources (new file-like things)
 
     This view creates new objects in containers.
@@ -89,10 +90,10 @@ class NullPUT(object):
         request.response.setStatus(201)
         request.response.setHeader(
             'Location', zope.traversing.browser.absoluteURL(newfile, request))
-        return ''
+        return b''
 
 
-class FilePUT(object):
+class FilePUT:
     """Put handler for existing file-like things
 
     """
@@ -112,4 +113,4 @@ class FilePUT(object):
         length = int(self.request.get('CONTENT_LENGTH', -1))
         adapter.write(body.read(length))
 
-        return ''
+        return b''
