@@ -16,14 +16,17 @@ We also never traverse to views.
 """
 __docformat__ = 'restructuredtext'
 
-from zope.publisher.interfaces.http import IHTTPPublisher
-from zope.container.interfaces import ISimpleReadContainer, IItemContainer
-from zope.app.http.put import NullResource
+from zope.container.interfaces import IItemContainer
+from zope.container.interfaces import ISimpleReadContainer
+from zope.interface import implementer
 from zope.publisher.interfaces import NotFound
-from zope.interface import implements
+from zope.publisher.interfaces.http import IHTTPPublisher
 
-class ContainerTraverser(object):
-    implements(IHTTPPublisher)
+from zope.app.http.put import NullResource
+
+
+@implementer(IHTTPPublisher)
+class ContainerTraverser:
     __used_for__ = ISimpleReadContainer
 
     def __init__(self, container, request):
@@ -46,11 +49,12 @@ class ContainerTraverser(object):
             raise NotFound(self.context, name, request)
 
         # This should only happen for a PUT or MKCOL:
-        if request.method not in  ['PUT', 'MKCOL']:
+        if request.method not in ['PUT', 'MKCOL']:
             raise NotFound(self.context, name, request)
 
         return NullResource(self.context, name)
 
+
 class ItemTraverser(ContainerTraverser):
     __used_for__ = IItemContainer
 
